﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.Diagnostics;

namespace esl
{
    class MortgageLoanApplication
    {
        private static string API_KEY = "";
        private static string API_URL = ""; //e.g. https://sandbox.esignlive.com/api

        public static void start()
        {
            EslClient eslClient = new EslClient(API_KEY, API_URL);

            DocumentPackage documentPackage = PackageBuilder.NewPackageNamed("Mortgage Loan Application")
                .WithSigner(SignerBuilder.NewSignerWithEmail("mail30@mailinator.com")
                        .WithFirstName("John")
                        .WithLastName("Smith")
                        .WithCustomId("Signer1"))
                .WithSigner(SignerBuilder.NewSignerWithEmail("mail32@mailinator.com")
                        .WithFirstName("Patty")
                        .WithLastName("Galant")
                        .WithCustomId("Signer2"))
                .WithDocument(DocumentBuilder.NewDocumentNamed("Mortgage Loan Agreement")
                        .FromFile("../mortgage-loan.pdf")
                        .EnableExtraction()
                        .WithExtractionType(ExtractionType.TEXT_TAGS_ONLY)
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("applicant_name")
                                .WithValue("John Smith"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("applicant_email")
                                .WithValue("mail30@mailinator.com"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("application_number")
                                .WithValue("1143216218"))
                        )
                .WithDocument(DocumentBuilder.NewDocumentNamed("Appraisal Form")
                        .FromFile("../appraisal-form.pdf")
                        .EnableExtraction()
                        .WithExtractionType(ExtractionType.TEXT_TAGS_ONLY)
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("coapplicant_name")
                                .WithValue("Patty Galant"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("coapplicant_email")
                                .WithValue("mail32@mailinator.com"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("coapplicant_name")
                                .WithValue("Patty Galant"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("application_number")
                                .WithValue("1143216218"))
                        )
                .Build();

            PackageId packageId = eslClient.CreatePackage(documentPackage);

            List<string> signerIdsList1 = new List<string>();
            signerIdsList1.Add("Signer1");
            signerIdsList1.Add("Signer2");

            List<string> signerIdsList2 = new List<string>();
            signerIdsList2.Add("Signer2");

            Silanis.ESL.SDK.DocumentVisibility visibility = DocumentVisibilityBuilder.NewDocumentVisibility()
                    .AddConfiguration(DocumentVisibilityConfigurationBuilder.NewDocumentVisibilityConfiguration(DOC1_ID)
                            .WithSignerIds(signerIdsList1))
                    .AddConfiguration(DocumentVisibilityConfigurationBuilder.NewDocumentVisibilityConfiguration(DOC2_ID)
                            .WithSignerIds(signerIdsList2))
                    .Build();

            eslClient.ConfigureDocumentVisibility(packageId, visibility);

           eslClient.SendPackage(packageId);
        }
    }
}
